@@ -1,5 +1,5 @@
 package Bot::Cobalt::Serializer;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use 5.10.1;
 use strictures 1;
@@ -15,6 +15,7 @@ use Fcntl qw/:flock/;
 
 use Bot::Cobalt::Common qw/:types/;
 
+use Time::HiRes qw/sleep/;
 
 has 'Format' => (
   is  => 'rw', 
@@ -289,8 +290,8 @@ sub _write_serialized {
       confess "Failed writefile lock ($path), timed out ($timeout)"
         if $timer > $timeout;
 
-      select undef, undef, undef, 0.1;
-      $timer += 0.1;
+      sleep 0.01;
+      $timer += 0.01;
     }
 
   }
